ContentSpecValidationContext

Struct ContentSpecValidationContext 

pub struct ContentSpecValidationContext { /* private fields */ }

Implementations

Source

impl ContentSpecValidationContext

pub fn push_name(&mut self, name: &str)

pub fn push_pcdata(&mut self)

pub fn push_whitespaces(&mut self)

pub fn push_misc(&mut self)

In element content validation, it can be treated almost the same as whitespace.
However, in standalone document validation, whitespace and other Miscs are treated differently.

pub fn finish(&mut self) -> bool