XIncludeProcessor

Struct XIncludeProcessor 

pub struct XIncludeProcessor<'a, H: SAXHandler = DefaultSAXHandler, R: XIncludeResourceResolver = XIncludeDefaultResourceResolver> {
    pub reader: XMLReader<DefaultParserSpec<'a>, TreeBuildHandler<H>>,
    pub resolver: R,
    /* private fields */
}
XInclude processor.

Fields

reader: XMLReader<DefaultParserSpec<'a>, TreeBuildHandler<H>>resolver: R

Implementations

Source

impl<H: SAXHandler, R: XIncludeResourceResolver> XIncludeProcessor<'_, H, R>

pub fn new<'a>( reader: XMLReader<DefaultParserSpec<'a>, TreeBuildHandler<H>>, resolver: R, ) -> XIncludeProcessor<'a, H, R>

Build an XInclude processor from a parser that constructs the document tree of XML resources and a resource resolver for XInclude processing.

XInclude processing errors are notified through the reader’s error handler.

pub fn process(&mut self, document: Document) -> Result<Document, XMLError>

Apply XInclude processing to document.

XInclude processing is not performed in-place; therefore, this method always returns a deep copy when processing succeeds.

pub fn process_subtree( &mut self, root: Node<dyn NodeSpec>, ) -> Result<Node<dyn NodeSpec>, XMLError>

Apply XInclude processing to the subtree whose root is root.

XInclude processing is not performed in-place; therefore, this method always returns a deep copy when processing succeeds.

In addition to the usual XInclude processing errors, errors may occur when the root is detached from the Document node, due to the inability to properly obtain the base URI.