evaluate_uri

Function evaluate_uri 

pub fn evaluate_uri(
    xpath: &str,
    uri: impl AsRef<URIStr>,
    encoding: Option<&str>,
) -> Result<XPathObject, XMLError>
Parse the XML document where uri is the base URI of the source, and evaluate xpath as an XPath expression.

If successfully executed, it returns an XPathObject representing the evaluation result of the XPath expression.
If the compilation or evaluation of the XPath expression fails, or if the XML document cannot be parsed, it returns Err.

encoding allows you to optionally specify the preferred encoding method to use.