pub type ElementDecl = Node<ElementDeclSpec>;Aliased Type
pub struct ElementDecl { /* private fields */ }Implementations
Sourceimpl ElementDecl
impl ElementDecl
Sourcepub fn content_spec(&self) -> Ref<'_, ContentSpec>
pub fn content_spec(&self) -> Ref<'_, ContentSpec>
ContentSpec of declaration target element.
Sourcepub fn deep_copy(&self) -> Self
pub fn deep_copy(&self) -> Self
Create new node and copy internal data to the new node.
While Clone::clone merely copies the pointer, this method copies the internal data
to new memory, creating a completely different node. Comparing the source node and
the new node using Node::is_same_node will always return false.